@@ -107,6 +107,7 @@ class tagObject(object):
         self.__foundPhrase = ''
         self.__foundDict = {}
         self.__ConTextCategory = ConTextCategory
+        self.__category = self.__item.getCategory()
         self.__tagID = tagid
         if( scope == None ):
             self.__scope = []
@@ -181,7 +182,9 @@ class tagObject(object):
         return self.__item.getLiteral()
     def getCategory(self):
         """returns the category (e.g. CONJUNCTION) for this object"""
-        return self.__item.getCategory()
+        return self.__category
+    def setCategory(self,category):
+        self.__category = category
     def setSpan(self,span):
         """set the span within the associated text for this object"""
         self.__spanStart = span[0]
